#ifndef BOOST_SIMD_INCLUDE_CONSTANTS_SIGNMASK_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_CONSTANTS_SIGNMASK_HPP_INCLUDED

#include <boost/simd/constant/include/constants/signmask.hpp>

#endif
